package com.tourism.webadmin.app.website.service.impl;

import com.tourism.common.additional.constant.CacheConstants;
import com.tourism.common.additional.redis.RedisCache;
import com.tourism.common.additional.utils.StringUtils;
import com.tourism.webadmin.app.website.service.LoginToWebsiteService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.stereotype.Service;

/**
 * 注册校验方法
 * 
 * @author tourism
 */
@Slf4j
@Service("LoginToWebsiteService")
public class LoginToWebsiteServiceImpl implements LoginToWebsiteService
{
    @Autowired
    private RedisCache redisCache;

    /**
     * 校验验证码
     *
     * @param code 验证码
     * @param uuid 唯一标识
     * @return 结果
     */
    @Override
    public boolean validateCaptcha(String uuid, String code)
    {
        String verifyKey = CacheConstants.CAPTCHA_CODE_KEY + StringUtils.nvl(uuid, "");
        String captcha = redisCache.getCacheObject(verifyKey);
        redisCache.deleteObject(verifyKey);
        if (captcha == null || !(captcha.equals(code.toLowerCase())))
        {
            return false;
        }
        return true;
    }
    /**
     * 校验短信验证码
     *
     * @param mobile 手机号
     * @param smsCode 短信验证码
     * @return 结果
     */
    @Override
    public boolean validateSmsCode(String mobile,String smsCode){
        String cacheObject = redisCache.getCacheObject(mobile);
        redisCache.deleteObject(mobile);
        if(cacheObject == null || !(smsCode.equals(cacheObject.toLowerCase())) ){
            return false;
        }
        return true;
    }
}
